
=======
Stimela
=======

**NOTE** This is the repository for *Stimela Classic* (i.e. version 1.x) which is no longer actively developed -- only maintenance releases are done occasionally. New to Stimela and want to write YaML recipes? Then you're certainly looking for the shiny new `Stimela 2 <https://github.com/caracal-pipeline/stimela>`.


|Pypi Version|
|Build Version|  

To reference *stimela* in a scholary work, please use this citation:

.. code-block:: latex

 @phdthesis{makhathini2018,
  author       = {Makhathini, S.},
  title        = {Advanced radio interferometric simulation and data reduction techniques},
  school       = {Rhodes University},
  year         = 2018,
  address      = {Drosty Rd, Grahamstown, 6139, Eastern Cape, South Africa},
  month        = 4,
  note         = {Available via \url{http://hdl.handle.net/10962/57348}}}


`Documentation <https://github.com/SpheMakh/Stimela/wiki>`_  
===========================================================

`Installation <https://github.com/SpheMakh/Stimela/wiki/Installation>`_
=======================================================================

`Tutorials <https://github.com/SpheMakh/Stimela/wiki/Examples>`_
================================================================


This project was initially funded by the `SKA/AWS AstroCompute In The Cloud <https://www.skatelescope.org/ska-aws-astrocompute-call-for-proposals>`_ initiative.


.. |Pypi Version| image:: https://img.shields.io/pypi/v/stimela.svg
                  :target: https://pypi.python.org/pypi/stimela
                  :alt:
.. |Build Version| image:: https://travis-ci.org/SpheMakh/Stimela.svg?branch=master
                  :target: https://travis-ci.com/Sphemakh/Stimela/
                  :alt:

.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/stimela.svg
                     :target: https://pypi.python.org/pypi/stimela
                     :alt:
